@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-from typing import Iterable, Union
+from typing import Callable, Iterable, Union
 import sys
 from threading import Timer
 from time import sleep
@@ -122,21 +122,32 @@ def create_full_list(amount, lst, cmp = None):
 
 class SetInterval:
     """
-    Set interval 
-  @param interval:
-    Time to perform function.
-    In Seconds
-  @param  Function:
-    function to perform
-  @param  end:
-    Time to end interval after
-    Defaults to 1000 seconds
-  @param lock:
-    If to allow execution of other codes 
+    Sets an interval for functions.
+    
     """
 
-    def __init__(self, interval:Union[int, float], function, end:int=1000, callback:bool=None, \
+    def __init__(self, interval:Union[int, float], function, end:int=1000, callback:Callable=None, \
                 show_progress:bool=False, req:bool=False, args:list=None, kwargs:dict=None):
+        """Creates an instance of SetInterval
+        
+        parameters
+        ----------
+        interval : Union[int, float]
+            time between intervals
+        function: Callable
+            the function to call
+        end: int
+            number of times to run
+        callback: Callable
+            function to call after code run
+        show_progress: bool
+            If to show a progress bar to indicate running #buggy
+        req: bool
+            if to add self to the called function. usefull if function should cancel the interval
+        args: Iterable
+            List of arguments
+        kwargs: dict
+            List of named arguments"""
         global k, val
         self.k = k
         self.callback = callback
@@ -190,6 +201,7 @@ class SetInterval:
         self.k2.start()
 
     def cancel(self):
+        "Cancel running Interval"
         self.k = self.end
         self.k2.cancel()
         if self.callback is not None: 
@@ -235,7 +247,8 @@ class Print:
               'black', 'yellow', "cyan"]
 
     @staticmethod
-    def get_colors():
+    def get_colors() -> list:
+        "Returns the list of colors availiable"
         return Print.colors[:]
     
     @staticmethod
@@ -285,11 +298,27 @@ class Print:
                 raise TimeoutError
 
     def __init__(self, *text, fg=None, bg=None, time=0.03, lock=True, end="\n", format=False):
+        """Prints any amount of text with the given color and background.
+            parameters
+            ----------
+            text: Iterable
+                Items to print out. Can be anything
+            fg: str
+                Foreground color
+            bg: str
+                Background color
+            lock: bool
+                If lock is true, there will be no access to the console till the printing is over.
+            end: str
+                Character to end with
+            format: bool
+                If format is true, any item in @param 'text' that is a dict, will be formated with json.dumps with indent of 2"""
         for ind, content in enumerate(text, 0):
             self.i = 0
             if type(content) is dict or type(content) is list and format:
                 content = dumps(content, indent=2)
-            self.text = [x for x in str(content)]
+            else:
+                self.text = [x for x in str(content)]
             self.inter = None
             self.color = Print._process_color(fg)
             self.bg_color = Print._process_color(bg)
@@ -321,8 +350,25 @@ class MultiColoredPrint:
     """
     @staticmethod
     def get_colors():
+        "Returns all the accepted colors."
         return Print.colors
+
     def __init__(self, *args, color: Iterable = "", bg: Iterable = "", delimiter=" ", time = 0, lock: bool = True):
+        """ Prints multiple text with multiple colors, different backgrounds and a special delimiter after each color. 
+            parameters
+            ----------
+            args: Iterable
+                Items to print
+            color: str
+                Foreground color
+            bg: str
+                Background color
+            delimiter: str
+                Character to print out after every item
+            time: int | float
+                Time for each item
+            lock: bool
+                If lock is true, there will be no access to the console till the printing is over."""
         args = [str(x) for x in args]
         color = list(color)
         color.reverse()
@@ -381,7 +427,25 @@ class ProgressBar:
         if self.len > 20:
             self.diff = self.len//20
             self.len = 20
+
     def __init__(self, len=10, color="", bg="", char="#", **kwargs):
+        """Creates a progress bar with the given length, color, background and character.
+        >>> from niceprint import ProgressBar as pb
+        >>> progress = pb(color='c', bg='k')
+        >>> progress.fill(ms=10)
+        [#         ]
+        parameters
+        ----------
+        len: int
+            Length of progress bar
+        color: str
+            Foreground color
+        bg: str
+            Background Color
+        char: str
+            Character in bar
+        """
+    
         self.len = len
         self._old_len = len
         self._process_len()
@@ -390,7 +454,7 @@ class ProgressBar:
         self.bg_color = Print._process_color(bg)
         self.tick = 0
         self.charcter = char
-        if char==" ":
+        if char==" " or char == "":
             color = ""
             if bg == "":
                 self.bg_color = Print._process_color("b")
@@ -424,14 +488,42 @@ class ProgressBar:
         sys.stdout.flush()
         
     def set_len(self, len):
+        "Set the length of the progress bar"
         self.len = len
         self.pulse()
     
     def clean_up(self, *args):
+        "Cleans the line it's on"
         sys.stdout.write(u"\u001b[10000000000D")
         sys.stdout.flush()
+    
+    def empty(self, *args):
+        "Empties the progress bar"
+        self.pg = 0
+        self.chw = 0
         
     def fill(self, ms=10, sec=None, text = ""):
+        """Fill up the progress bar according to time.
+        >>> from niceprint import ProgressBar as pb
+        >>> progress = pb(2, 'c', 'r')
+        >>> progress.fill(text = ['One text'])
+        [# ] One text
+        [##] One text
+        >>> progress.empty()
+        >>> progress.fill(text = ['Text 1', 'Text 2'])
+        [# ] Text 1
+        [##] Text 2
+
+        parameters
+        ----------
+        ms: int 
+            Time between each pulse in milliseconds
+        sec: int | float
+            Time between each pulse in seconds
+        text: str | list | Tuple
+            Items to print at the end of the bar
+
+        """
         char=self.char
         self.len = self.len-self.pg
         if sec is not None:
@@ -445,7 +537,9 @@ class ProgressBar:
             sys.stdout.write(u"\u001b[1000D"+bar)
             sys.stdout.flush()
         print()
-    def set_color(self, color):
+    def set_color(self, color) -> bool:
+        """Sets the backgroun color of the char in the bar
+        returns True if color has been set else False"""
         if color != "":
             try:
                 color = Print._process_color(color)
@@ -456,7 +550,22 @@ class ProgressBar:
                 print(e)
                 return False
             return True
-    def set_char(self, char, *args):
+    def set_bgcolor(self, color) -> bool:
+        """Sets the backgroun color of the char in the bar
+        returns True if color has been set else False"""
+        if color != "":
+            try:
+                color = Print._process_color(color)
+                self.char = eval(f"bg_{color}")(self.charcter)
+                self.bg_color = color
+            except Exception as e:
+                color = ""
+                print(e)
+                return False
+            return True
+    def set_char(self, char, *args) -> bool:
+        """Sets the character of the progress bar
+        returns True if char has been set else False"""
         try:
             self.char = eval(f"{self.color}")(char)
             self.charcter = char
@@ -466,6 +575,16 @@ class ProgressBar:
             return False
 
     def pulse(self, step=1, ms=1, sec=None, text: str = ""):
+        """Increase the progress bar by amount of step and with a text
+        parameters
+        ----------
+        ms: int 
+            Time between each pulse in milliseconds
+        sec: int | float
+            Time between each pulse in seconds
+        text: str 
+            String to print at the end of the bar
+        """
         if step > 1:
             self.len = self._old_len*2
             self._process_len()
@@ -493,9 +612,22 @@ class Spinner:
         print()
 
     def __init__(self, fg="c", bg = "", *args):
+        """Creates a spinner
+        >>> from niceprint import Spinner
+        >>> sp = Spinner()
+        >>> sp.rotate()
+
+        parameters
+        ----------
+        fg: str
+            Foreground color
+        bg: str
+            Background color
+        
+        """
         self.color = Print._process_color(fg)
         self.bg = Print._process_color(bg)
-        self._chars = [" | ", " / ", " - ", " \\ "]
+        self._chars = [" | ", " / ", " -- ", " \\ "]
         self._index = 0
         sys.stdout.flush()
 
@@ -507,12 +639,22 @@ class Spinner:
         return ch
 
     def spin(self, *args):
+        "Turns the spinner 1 step"
         sys.stdout.write(u"\u001b[10000D"+" "*100)
         sys.stdout.write(u"\u001b[10000D" + self._get_char())
         sys.stdout.flush()
 
     def rotate(self, times: int = 5, time: int = 0.1, text: Union[str, list] = ""):
-        "Rotates the spiner N(times) with a time interval of T(time)"
+        """Rotates the spiner N(times) with a time interval of T(time)
+        parameters
+        ----------
+        times: int 
+            Times to rotate
+        time: int | float
+            Time between each turn in seconds
+        text: str | list | Tuple
+            Items to print at the end of the bar
+        """
         
         for _ in range(times):
             if type(text) is list:
@@ -532,7 +674,22 @@ class Spinner:
         sys.stdout.flush()
 
 class Percentage:
-    def __init__(self, fg, bg, max = 100):
+    def __init__(self,max = 100, fg="", bg=""):
+        """Creates a percentage class
+        >>> from niceprint import Percentage
+        >>> pg = Percentage(10)
+        >>> pg.tick()
+        0%
+        >>> pg.fill(text = ['Starting...', 'Almost Done', 'Just a sec..'])
+        parameters
+        ----------
+        max: int
+            Maximum number
+        fg: str
+            Foreground color
+        bg: str
+            Background color
+        """
         self.fg = Print._process_color(fg)
         self.bg = Print._process_color(bg)
         self.max = max
@@ -542,12 +699,21 @@ class Percentage:
         return eval(f"bg_{self.bg}")(eval(f"{self.fg}")(str(self.start)+"%")) + " "
 
     def tick(self, text = ""):
+        "Increases the percentage value by 1 with an optional text at the end"
         sys.stdout.write(u"\u001b[10000D"+" "*100)
         sys.stdout.write(u"\u001b[10000D"+self._get_point()+str(text))
         sys.stdout.flush()
         self.start += 1
     
-    def fill(self, time: int = 0, text: Union[str, list] = ""):
+    def fill(self, time: Union[int, float] = 0, text: Union[str, list] = ""):
+        """Increases the percentage value till the end with multiple or single text
+        parameters
+        ----------
+        time: int | float
+            Time between each increment in seconds
+        text: str | list | Tuple
+            Items to print at the end of the bar
+            """
         if type(text) is list:
             text = create_full_list(self.max - self.start, text)
 
